//
//  This file is part of Siena, a wide-area event notification system.
//  See http://www.inf.unisi.ch/carzaniga/siena/
//
//  Author: Antonio Carzaniga (firstname.lastname@unisi.ch)
//  See the file AUTHORS for full details. 
//
//  Copyright (C) 1998-2002 University of Colorado
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
//  USA, or send email to Antonio Carzaniga (firstname.lastname@unisi.ch).
//
package siena;
import siena.comm.*;

import java.io.BufferedReader;
import java.io.InputStreamReader;

public class Sender {
    static PacketSenderFactory sender_factory = new GenericSenderFactory();
    public static void main(String[] args) {
	try {
	    BufferedReader in
		= new BufferedReader(new InputStreamReader(System.in));
	    SENPPacket packet = new SENPPacket();
	    String inl;
	    int usec = 500;
	    if (args.length > 0) {
		usec = Integer.decode(args[0]).intValue();
	    }
	    while ((inl = in.readLine()) != null) {
		byte [] pkt = inl.getBytes();
		if (pkt.length > 0 && pkt[0] != 0x23 /* '#' */) {
		    packet.init(pkt);
		    packet.decode();
		    // skip blank lines and comments
		    if (packet.to == null) {
			System.err.println("bad input format");
			System.exit(1);
		    }
		    try {
			//
			// here I create, use, and destroy a sender
			// for each packet.  Perhaps a sender cache
			// would work be more efficient, but it would
			// leave a lot of connectors (namely KA
			// connectors) hanging there with no traffic,
			// which might delay some packets, thereby
			// screwing up my tests that depend on that...
			//
			PacketSender server;
			server = sender_factory.createPacketSender(new String(packet.to));
			server.send(pkt);
			server.shutdown();
			server = null;
		    } catch (Exception ex) {
			ex.printStackTrace();
			System.exit(1);
		    }
		    Thread.sleep(usec);
		}
	    }
	} catch (Exception ex) {
	    ex.printStackTrace();
	    System.exit(1);
	}
    }
}
